@@ -12,14 +12,14 @@ use sn_data_types::{
     ActorHistory, Blob, CreditAgreementProof, NodeAge, PublicKey, RewardAccumulation,
     RewardProposal, SignedTransfer, TransferAgreementProof,
 };
-use sn_messaging::client::{ClientMsg, CmdError};
+use sn_messaging::client::ClientMsg;
 use sn_messaging::{
     client::{
-        BlobRead, BlobWrite, DataExchange, ProcessMsg, ProcessingError, QueryResponse,
-        SupportingInfo,
+        BlobRead, BlobWrite, ClientSigned, DataCmd, DataExchange, DataQuery, ProcessMsg,
+        ProcessingError, QueryResponse, SupportingInfo,
     },
     node::NodeMsg,
-    Aggregation, DstLocation, EndUser, MessageId, Msg, SrcLocation,
+    Aggregation, DstLocation, EndUser, MessageId, SrcLocation,
 };
 use sn_routing::Prefix;
 use std::{
@@ -75,6 +75,7 @@ pub enum NodeDuty {
     RegisterTransfer {
         proof: TransferAgreementProof,
         msg_id: MessageId,
+        origin: SrcLocation,
     },
     /// TEMP: Simulate a transfer from a client
     SimulatePayout {
@@ -89,20 +90,13 @@ pub enum NodeDuty {
     WriteChunk {
         write: BlobWrite,
         msg_id: MessageId,
-        origin: EndUser,
+        client_signed: ClientSigned,
     },
     ProcessRepublish {
         chunk: Blob,
         msg_id: MessageId,
     },
     /// Run at data-section Elders on receiving the result of
-    /// write operations from Adults
-    RecordAdultWriteLiveness {
-        result: Result<(), CmdError>,
-        correlation_id: MessageId,
-        src: XorName,
-    },
-    /// Run at data-section Elders on receiving the result of
     /// read operations from Adults
     RecordAdultReadLiveness {
         response: QueryResponse,
@@ -215,14 +209,16 @@ pub enum NodeDuty {
     },
     /// Process read of data
     ProcessRead {
-        query: sn_messaging::client::DataQuery,
+        query: DataQuery,
         msg_id: MessageId,
+        client_signed: ClientSigned,
         origin: EndUser,
     },
     /// Process write of data
     ProcessWrite {
-        cmd: sn_messaging::client::DataCmd,
+        cmd: DataCmd,
         msg_id: MessageId,
+        client_signed: ClientSigned,
         origin: EndUser,
     },
     /// Process Payment for a DataCmd
@@ -268,15 +264,6 @@ impl Debug for NodeDuty {
             Self::ReadChunk { .. } => write!(f, "ReadChunk"),
             Self::WriteChunk { .. } => write!(f, "WriteChunk"),
             Self::ProcessRepublish { .. } => write!(f, "ProcessRepublish"),
-            Self::RecordAdultWriteLiveness {
-                correlation_id,
-                result,
-                src,
-            } => write!(
-                f,
-                "RecordAdultWriteLiveness {{ correlation_id: {}, result: {:?}, src: {} }}",
-                correlation_id, result, src
-            ),
             Self::RecordAdultReadLiveness {
                 correlation_id,
                 response,
@@ -339,22 +326,6 @@ pub enum MsgType {
     Client(ClientMsg),
 }
 
-impl MsgType {
-    pub fn id(&self) -> MessageId {
-        match self {
-            Self::Node(msg) => msg.id(),
-            Self::Client(msg) => msg.id(),
-        }
-    }
-
-    pub fn convert(msg: MsgType) -> Msg {
-        match msg {
-            Self::Client(msg) => Msg::Client(msg),
-            Self::Node(msg) => Msg::Node(msg),
-        }
-    }
-}
-
 #[derive(Debug, Clone)]
 pub struct OutgoingLazyError {
     pub msg: ProcessingError,
@@ -366,21 +337,3 @@ pub struct OutgoingSupportingInfo {
     pub msg: SupportingInfo,
     pub dst: DstLocation,
 }
-
-impl OutgoingMsg {
-    pub fn id(&self) -> MessageId {
-        self.msg.id()
-    }
-}
-
-impl OutgoingLazyError {
-    pub fn id(&self) -> MessageId {
-        self.msg.id()
-    }
-}
-
-impl OutgoingSupportingInfo {
-    pub fn id(&self) -> MessageId {
-        self.msg.id()
-    }
-}
